@@ -19,7 +19,7 @@ use Helios::LogEntry::Levels qw(:all);
 use Helios::TheSchwartz;
 use Helios::Config;
 
-our $VERSION = '2.50_3070';
+our $VERSION = '2.50_3630';
 
 =head1 NAME
 
@@ -231,7 +231,7 @@ our %DEFAULTS = (
     ZERO_SLEEP_INTERVAL => 10,
     REGISTRATION_INTERVAL => 60,
     WORKER_BLITZ_FACTOR => 1,
-    DOUBLE_CLUTCH_INTERVAL => 20
+    WORKER_MAX_TTL_WAIT_INTERVAL => 20
 );
 our $CLEAN_SHUTDOWN = 1;				# used to determine if we should remove the PID file or not (at least for now)
 
@@ -252,7 +252,7 @@ our $SAFE_MODE_RETRIES = 5;				# SAFE MODE support; number of times to retry
 our $ZERO_SLEEP_INTERVAL;				# to reduce needless checking of the database
 our $ZERO_SLEEP_LOG_INTERVAL = 3600;	# to reduce needless log msgs in log_tb
 our $ZERO_SLEEP_LOG_LAST = 0;
-our $DOUBLE_CLUTCH_INTERVAL = 20;		# for WORKER_MAX_TTL functionality
+our $WORKER_MAX_TTL_WAIT_INTERVAL = 20;		# for WORKER_MAX_TTL functionality
 
 our $WORKER_PROCESS = 0;				# used to indicate process has become a worker process
 										# this is used in addition to getppid() to prevent workers
@@ -340,10 +340,10 @@ if ( defined($params->{WORKER_BLITZ_FACTOR}) ) {
 } else {
 	$WORKER_BLITZ_FACTOR = $DEFAULTS{WORKER_BLITZ_FACTOR};
 }
-if ( defined($params->{DOUBLE_CLUTCH_INTERVAL}) ) {
-	$DOUBLE_CLUTCH_INTERVAL = $params->{DOUBLE_CLUTCH_INTERVAL};
+if ( defined($params->{WORKER_MAX_TTL_WAIT_INTERVAL}) ) {
+	$WORKER_MAX_TTL_WAIT_INTERVAL = $params->{WORKER_MAX_TTL_WAIT_INTERVAL};
 } else {
-	$DOUBLE_CLUTCH_INTERVAL = $DEFAULTS{DOUBLE_CLUTCH_INTERVAL};	
+	$WORKER_MAX_TTL_WAIT_INTERVAL = $DEFAULTS{WORKER_MAX_TTL_WAIT_INTERVAL};	
 }
 
 # make a globally accessible database handle 
@@ -745,7 +745,7 @@ sub double_clutch {
     # sleep $ZERO_LAUNCH_INTERVAL secs before we double check on workers
 #[]old    sleep $ZERO_LAUNCH_INTERVAL;
 #[]old    sleep $ZERO_LAUNCH_INTERVAL;
-	sleep $DOUBLE_CLUTCH_INTERVAL;
+	sleep $WORKER_MAX_TTL_WAIT_INTERVAL;
     foreach my $pid (keys %workers) {
         my $time_of_death = $workers{$pid} + $params->{WORKER_MAX_TTL};
         if ( time() > $time_of_death ) {
